#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_FRAC_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_FRAC_HPP_INCLUDED

#include <boost/simd/ieee/include/functions/frac.hpp>

#endif
